@@ -12,23 +12,24 @@ from aws_xray_sdk.ext.flask.middleware import XRayMiddleware
 from aws_xray_sdk.ext.flask_sqlalchemy.query import XRayFlaskSqlAlchemy
 from aws_xray_sdk.ext.util import construct_xray_header, inject_trace_header
 from celery import signals
-from core.instrumentation.logging import log
 
 
 class XRayConfigurator:
     def __init__(self, settings, application) -> None:
         if isinstance(settings, ConfigParser):
-            self._init_xray(settings.get("XRAY", "ENABLED", False),
-                            settings.get("XRAY", "SERVICE_NAME"),
-                            settings.get("XRAY", "PLUGINS", "'ECSPlugin', 'EC2Plugin'"),
-                            settings.get("XRAY", "SAMPLING", False),
-                            settings.get("XRAY", "STREAM_SQL", True),
-                            settings.get("XRAY", "DAEMON", "xray-daemon:2000"),
-                            settings.get("XRAY", "PATCH_MODULES", None),
-                            settings.get("XRAY", "SQLALCHEMY", True),
-                            settings.get("XRAY", "LOGGING_ENABLED", False),
-                            settings.get("XRAY", "CELERY", False),
-                            application)
+            if "XRAY" in settings:
+                xray = settings["XRAY"]
+                self._init_xray(xray.get("ENABLED", False),
+                                xray.get("SERVICE_NAME"),
+                                xray.get("PLUGINS", "'ECSPlugin', 'EC2Plugin'"),
+                                xray.get("SAMPLING", False),
+                                xray.get("STREAM_SQL", True),
+                                xray.get("DAEMON", "xray-daemon:2000"),
+                                xray.get("PATCH_MODULES", None),
+                                xray.get("SQLALCHEMY", True),
+                                xray.get("LOGGING_ENABLED", False),
+                                xray.get("CELERY", False),
+                                application)
         else:
             self._init_xray(settings.XRAY_ENABLED,
                             settings.XRAY_NAME,
@@ -44,7 +45,7 @@ class XRayConfigurator:
 
     def _init_xray(self, enabled, name, plugins, sampling, stream_sql, daemon, patch_modules, sqlalchemy, logging_enabled, celery_enabled, application):
         if enabled:
-            log.info("xray sdk enabled " + str(enabled))
+            logging.info("xray sdk enabled " + str(enabled))
             global_sdk_config.set_sdk_enabled(True)
             xray_recorder.configure(service=name,
                                     plugins=eval(plugins),
@@ -58,24 +59,24 @@ class XRayConfigurator:
                 patch(eval(patch_modules))
 
             if sqlalchemy:
-                log.info("XRayFlaskSqlAlchemy enabled")
+                logging.info("XRayFlaskSqlAlchemy enabled")
                 XRayFlaskSqlAlchemy(application)
 
             XRayMiddleware(application, xray_recorder)
 
             if logging_enabled:
-                log.info("XRay logging enabled")
+                logging.info("XRay logging enabled")
                 logging.getLogger("aws_xray_sdk").setLevel(logging.DEBUG)
             else:
-                log.info("XRay logging disabled")
+                logging.info("XRay logging disabled")
                 logging.getLogger("aws_xray_sdk").setLevel(logging.NOTSET)
         else:
-            log.info("xray sdk disabled")
+            logging.info("xray sdk disabled")
             global_sdk_config.set_sdk_enabled(False)
 
 @signals.task_prerun.connect
 def task_prerun(task_id, task, *args, **kwargs):
-        log.info("task prerun task_id: " + task_id)
+        logging.info("task prerun task_id: " + task_id)
         xray_header = construct_xray_header(task.request)
         print(xray_header.root + " " + xray_header.parent)
         segment = xray_recorder.begin_segment(
@@ -88,12 +89,12 @@ def task_prerun(task_id, task, *args, **kwargs):
 
 @signals.task_postrun.connect()
 def task_postrun(task_id, *args, **kwargs):
-        log.info("task post run task_id: " + task_id)
+        logging.info("task post run task_id: " + task_id)
         xray_recorder.end_segment()
 
 @signals.before_task_publish.connect
 def before_task_publish(sender, headers, **kwargs):
-        log.info("before taskpublish sender: " + sender)
+        logging.info("before taskpublish sender: " + sender)
         current_segment = xray_recorder.current_segment()
         subsegment = xray_recorder.begin_subsegment(
             name=sender,
@@ -108,12 +109,12 @@ def before_task_publish(sender, headers, **kwargs):
 
 @signals.after_task_publish.connect
 def xray_after_task_publish(**kwargs):
-        log.info("after task publish")
+        logging.info("after task publish")
         xray_recorder.end_subsegment()
 
 @signals.task_failure.connect
 def xray_task_failure(einfo, **kwargs):
-        log.info("task_failure")
+        logging.info("task_failure")
         segment = xray_recorder.current_segment()
         if einfo:
             stack = stacktrace.get_stacktrace(limit=xray_recorder.max_trace_back)
